@@ -40,20 +40,39 @@ from ..utils import check_dir, write_PDB, write_pymol_script, sparse_corrcoef, r
 
 
 class LipidInteraction:
-    def __init__(self, trajfile_list, topfile_list=None, stride=1, dt_traj=None, cutoffs=[0.55, 1.0],
-                 lipid="POPC", lipid_atoms=None, nprot=1, resi_offset=0, save_dir=None, timeunit="us"):
-        """The main class to handle the calculation.
+    def __init__(self, trajfile_list, cutoffs=[0.475, 0.8], lipid="CHOL", topfile_list=None, lipid_atoms=None,
+                 nprot=1, resi_offset=0, save_dir=None, timeunit="us", stride=1, dt_traj=None):
 
-        *api* reads trajectory information via `mdtraj.load()`, and calculate the interactions
-        of specified lipids with the proteins or specified regions of the proteins in the systems.
+        """The outer layer class that integrates calculations and handles workflow.
+
+        `LipidInteraction` reads trajectory information via `mdtraj.load()`, and calculate interactions
+        of the specified lipid with the protein in the trajectories. `LipidInteraction` can calculate
+        interactions per protein residue and per binding site. 'LipidInteraction' also has a couple of assisting
+        functions to plot the interaction data and save the generated data.
 
         Parameters
         ----------
-        trajfile_list : str or list of str
-            A list of trajectory filenames. `mdtraj.load()` will load the trajectories one by one to read information.
-        topfile_list : str or list of str, optional, default=None
-            A list of topology filenames of the trajectories in *trajfile_list*. For those trajectory formats that
-            do not include topology information, `mdtraj.load()` requires a structure to read in
+        trajfile_list : str or a list of str
+            Trajectory filename(s) for `mdtraj.load()` to read the trajectory data.
+
+        cutoffs : float or a list of two floats, default=[0.475, 0.8]
+            Cutoff value(s) for defining contacts. When a list of two floats are supplied, the dual-cutoff scheme
+            will be used, whereas a single float
+
+        lipid : str, default="CHOL"
+            The lipid residue name.
+
+        topfile_list : str or a list of str, default=None
+            Topology filename(s). Most trajectory formats do not contain topology information. Pass in either
+            the path to a RCSB PDB file, a trajectory, or a topology for each trajectory in `trajfile_list`
+            to supply this information. See
+            `mdtraj.load() <https://mdtraj.org>`_. for more information.
+
+        stride : int, default=1
+            Only read every stride-th frame. The same as stride in mdtraj.load().
+
+        dt_traj : None or float, default=None
+
 
         """
         self._trajfile_list = np.atleast_1d(trajfile_list)
@@ -63,10 +82,16 @@ class LipidInteraction:
             self._topfile_list = [topfile_list for dummy in self._trajfile_list]
         else:
             raise ValueError(
-                "topfile_list should either have the same length as trajfile_list or have one valid file name")
+                "topfile_list should either have the same length as trajfile_list or have one valid file name.")
+
+        if len(np.atleast_1d(cutoffs)) == 1:
+            self._cutoffs = np.array([np.atleast_1d(cutoffs)[0] for dummy in range(2)])
+        elif len(np.atleast_1d(cutoffs)) == 2:
+            self._cutoffs = np.sort(np.array(cutoffs, dtype=float))
+        else:
+            raise ValueError("cutoffs should be either a float or a list of two flaots.")
 
         self._dt_traj = dt_traj
-        self._cutoffs = np.sort(np.array(cutoffs, dtype=float))
         self._lipid = lipid
         self._lipid_atoms = lipid_atoms
         self._nprot = int(nprot)
@@ -556,7 +581,7 @@ class LipidInteraction:
         ----------
         binding_site_id : int or list_like or None, optional, default=None
         n_top_poses : int, optional, default=5
-        pose_format : str, optional, default="gro"
+        pose_format : str, optional, default="pdb"
         score_weights : dict or None, optional, default=None
         kde_bw : scalar, optional, default=0.15
         pca_component : int, float or ‘mle’, default=0.95
@@ -588,6 +613,9 @@ class LipidInteraction:
         RMSD_set = {}
         for bs_id in tqdm(selected_bs_id, desc="ANALYZE BOUND POSES"):
             # lipid_dist_per_atom shape: [n_lipid_atoms, n_bound_poses, n_BS_residues]
+            if len(pose_pool[bs_id]) == 0:
+                print(f"Binding Site {bs_id} is bogus! Possibly due to insufficient sampling.")
+                continue
             lipid_dist_per_atom, pose_traj = vectorize_poses(pose_pool[bs_id], self._node_list[bs_id],
                                                              self._protein_ref, self._lipid_ref)
             if n_top_poses > 0:
